{
  lib,
  buildPythonPackage,
  fetchFromGitHub,
  cmake,
  ninja,
  cmake-build-extension,
  numpy,
  setuptools,
  setuptools-scm,
  wheel,
  eigen,
  libxml2,
  assimp,
  swig,
  pybind11,
}:

buildPythonPackage rec {
  pname = "idyntree";
  version = "13.1.1";
  pyproject = true;

  src = fetchFromGitHub {
    owner = "robotology";
    repo = "idyntree";
    rev = "v${version}";
    hash = "sha256-OD00X5xjcti7GthAkluM7GxUHZ9tl0ne4HhflHsW2qk=";
  };

  nativeBuildInputs = [ swig pybind11 ];

  buildInputs = [ assimp eigen libxml2.dev ];

  build-system = [
    cmake
    ninja
    cmake-build-extension
    numpy
    setuptools
    setuptools-scm
    wheel
  ];

  dontUseCmakeConfigure = true;

  cmakeFlags = [
    "-DIDYNTREE_USES_PYTHON_PYBIND11='ON'"
  ];

  pythonImportsCheck = [
    "idyntree"
  ];

  meta = {
    description = "Multibody Dynamics Library designed for Free Floating Robots";
    homepage = "https://github.com/robotology/idyntree";
    changelog = "https://github.com/robotology/idyntree/blob/${src.rev}/CHANGELOG.md";
    license = lib.licenses.bsd3;
    maintainers = with lib.maintainers; [ ];
  };
}
