{
  lib,
  buildPythonPackage,
  fetchFromGitHub,
  cmake,
  ninja,
  cmake-build-extension,
  #idyntree,
  setuptools,
  setuptools-scm,
  wheel,
  tiny-process-library,
  ycm,
  pkg-config,
  fetchgit
}:

buildPythonPackage rec {
  pname = "scenario";
  version = "1.4.0";
  pyproject = true;

  src = fetchFromGitHub {
    owner = "movefasta";
    repo = "scenario";
    rev = "6bf8f7227778a55aef335599e8d127c061af5bf6";
    hash = "sha256-QWBVIr4WaPHLzoRNm8p781k3obvywP+s0YbqP1+Tzd0=";
  };

  patches = [ ./ignition.patch ];

  postPatch = ''
    substituteInPlace deps/CMakeLists.txt \
      --replace "GIT_REPOSITORY https://github.com/robotology/ycm.git" "SOURCE_DIR ${ycm.src}" \
      --replace "GIT_REPOSITORY https://gitlab.com/eidheim/tiny-process-library.git" "SOURCE_DIR ${tiny-process-library.src}" \
      --replace "SCENARIO_CALL_FROM_SETUP_PY AND NOT USE_IGNITION" "FALSE"
    substituteInPlace pyproject.toml --replace-fail '"idyntree>=3.1",' ""
    substituteInPlace setup.py --replace-fail 'cmake_depends_on=["idyntree"],' ""
  '';

  # nativeBuildInputs = [ pkg-config ];

  build-system = [
    cmake
    ninja
    cmake-build-extension
    #idyntree
    setuptools
    setuptools-scm
    wheel
  ];

  cmakeFlags = [
    "-DSCENARIO_USE_IGNITION=FALSE"
    "-DSCENARIO_BUILD_SHARED_LIBRARY=ON"
  ];

  dontUseCmakeConfigure = true;

  pythonImportsCheck = [
    "scenario"
  ];

  meta = {
    description = "";
    homepage = "https://github.com/movefasta/scenario";
    license = lib.licenses.mit;
    maintainers = with lib.maintainers; [ ];
  };
}
