{
  lib,
  buildPythonPackage,
  fetchFromGitHub,
  setuptools,
  wheel,
  beautifulsoup4,
  onnxruntime,
  # sahi,
  lap,
  matplotlib,
  numpy,
  opencv-python,
  pandas,
  pillow,
  psutil,
  py-cpuinfo,
  pyyaml,
  requests,
  scipy,
  seaborn,
  torch,
  torchvision,
  tqdm,
  ultralytics-thop,
  coverage,
  ipython,
  mkdocs,
  mkdocs-jupyter,
  #mkdocs-macros-plugin,
  mkdocs-material,
  mkdocs-redirects,
  #mkdocs-ultralytics-plugin,
  mkdocstrings,
  pytest,
  pytest-cov,
  coremltools,
  flatbuffers,
  h5py,
  keras,
  onnx,
  openvino,
  scikit-learn,
  tensorflow,
  #tensorflowjs,
  tensorstore,
  albumentations,
  #hub-sdk,
  pycocotools,
  #comet,
  dvclive,
  tensorboard,
  shapely,
  streamlit,
  pytestCheckHook,
}:

buildPythonPackage rec {
  pname = "ultralytics";
  version = "8.3.61";
  pyproject = true;

  src = fetchFromGitHub {
    owner = "ultralytics";
    repo = "ultralytics";
    rev = "v${version}";
    hash = "sha256-0BMOFjVSYDFj3vfDccMCHnM1FqHesXYMWR4yCSs4oac=";
  };

  build-system = [
    setuptools
    wheel
  ];

  dependencies = [
    lap
    matplotlib
    numpy
    opencv-python
    pandas
    pillow
    psutil
    py-cpuinfo
    pyyaml
    requests
    scipy
    seaborn
    torch
    torchvision
    tqdm
    ultralytics-thop
  ];

  optional-dependencies = {
    dev = [
      coverage
      ipython
      mkdocs
      mkdocs-jupyter
      #mkdocs-macros-plugin
      mkdocs-material
      mkdocs-redirects
      #mkdocs-ultralytics-plugin
      mkdocstrings
      pytest
      pytest-cov
    ];
    export = [
      coremltools
      flatbuffers
      h5py
      keras
      numpy
      onnx
      openvino
      scikit-learn
      tensorflow
      #tensorflowjs
      tensorstore
    ];
    extra = [
      albumentations
      #hub-sdk
      ipython
      pycocotools
    ];
    logging = [
      # comet
      dvclive
      tensorboard
    ];
    solutions = [
      shapely
      streamlit
    ];
  };

  preBuild = ''
    sed -i '/torchvision>=0.9.0/d' pyproject.toml
  '';

  nativeCheckInputs = [ 
    beautifulsoup4
    onnxruntime
    shapely
    # sahi
  ];

  pythonImportsCheck = [
    "ultralytics"
  ];

  meta = {
    description = "Ultralytics YOLO11";
    homepage = "https://github.com/ultralytics/ultralytics";
    license = lib.licenses.agpl3Only;
    maintainers = with lib.maintainers; [ ];
  };
}
